The purpose of the utilities folder is to solve issues with circular imports.

Modules in the utilities folder:
- May NOT import each other.
- May NOT import any other module from the openavmkit package.
- MAY import modules NOT from the openavmkit package.
